==> nuxt-graphql-middleware-1.1.3.tgz: package/lib/esm/plugin/index.js <==
const IS_DEV = process.env.NODE_ENV === 'development';
function log(action, path, message) {
    if (IS_DEV) {
        console.log(`[API - ${action}] ${message}: ${path}`);
    }
}
export class GraphqlMiddlewarePlugin {
    constructor(baseURL, headers, useCache) {
        this.baseURL = baseURL;
        this.headers = headers || {};
        if (useCache) {
            this.cache = new Map();
        }
    }
    query(name, variables) {
        var _a;
        const params = new URLSearchParams({
            name,
            variables: JSON.stringify(variables || {}),
        });
        const url = this.baseURL + '/query?' + params.toString();
        if ((_a = this.cache) === null || _a === void 0 ? void 0 : _a.has(url)) {
            log('query', url, 'Loading from cache');
            return Promise.resolve(this.cache.get(url));
        }
        log('query', url, 'Fetching');
        return fetch(url, {
            method: 'GET',
            credentials: 'include',
            headers: Object.assign({ 'Content-Type': 'application/json' }, this.headers),
        })
            .then((response) => {
            if (response.ok) {
                return response.json();
            }
            throw new Error('Server Error');
        })
            .then((data) => {
            var _a;
            if (this.cache && this.cache.size > 30) {
                const key = this.cache.keys().next().value;
                this.cache.delete(key);
            }
            (_a = this.cache) === null || _a === void 0 ? void 0 : _a.set(url, data);
            return data;
        });
    }
    mutate(name, variables) {
        const params = new URLSearchParams({
            name,
        });
        return fetch(this.baseURL + '/mutate?' + params.toString(), {
            method: 'POST',
            credentials: 'include',
            headers: Object.assign({ 'Content-Type': 'application/json' }, this.headers),
            body: JSON.stringify(variables),
        }).then((response) => response.json());
    }
}
const graphqlMiddlewarePlugin = (context, inject) => {
    var _a;
    const namespace = "<%= options.namespace || '' %>";
    const cacheInBrowser = "<%= options.cacheInBrowser || '' %>" === 'true';
    const cacheInServer = "<%= options.cacheInServer || '' %>" === 'true';
    let baseURL = namespace;
    if (process.server) {
        baseURL = 'http://0.0.0.0:3000' + namespace;
    }
    const useCache = (process.server && cacheInServer) || (process.client && cacheInBrowser);
    inject('graphql', new GraphqlMiddlewarePlugin(baseURL, (_a = context.req) === null || _a === void 0 ? void 0 : _a.headers, useCache));
};
export default graphqlMiddlewarePlugin;

==> nuxt-graphql-middleware-1.1.5.tgz: package/lib/esm/plugin/index.js <==
const IS_DEV = process.env.NODE_ENV === 'development';
function log(action, path, message) {
    if (IS_DEV) {
        console.log(`[API - ${action}] ${message}: ${path}`);
    }
}
export class GraphqlMiddlewarePlugin {
    constructor(baseURL, headers, useCache) {
        this.baseURL = baseURL;
        this.headers = headers || {};
        if (useCache) {
            this.cache = new Map();
        }
    }
    query(name, variables) {
        var _a;
        const params = new URLSearchParams({
            name,
            variables: JSON.stringify(variables || {}),
        });
        const url = this.baseURL + '/query?' + params.toString();
        if ((_a = this.cache) === null || _a === void 0 ? void 0 : _a.has(url)) {
            log('query', url, 'Loading from cache');
            return Promise.resolve(this.cache.get(url));
        }
        log('query', url, 'Fetching');
        return fetch(url, {
            method: 'GET',
            credentials: 'include',
            headers: Object.assign({ 'Content-Type': 'application/json' }, this.headers),
        })
            .then((response) => {
            if (response.ok) {
                return response.json();
            }
            throw new Error('Server Error');
        })
            .then((data) => {
            var _a;
            if (this.cache && this.cache.size > 30) {
                const key = this.cache.keys().next().value;
                this.cache.delete(key);
            }
            (_a = this.cache) === null || _a === void 0 ? void 0 : _a.set(url, data);
            return data;
        });
    }
    mutate(name, variables) {
        const params = new URLSearchParams({
            name,
        });
        return fetch(this.baseURL + '/mutate?' + params.toString(), {
            method: 'POST',
            credentials: 'include',
            headers: Object.assign({ 'Content-Type': 'application/json' }, this.headers),
            body: JSON.stringify(variables),
        }).then((response) => response.json());
    }
}
const graphqlMiddlewarePlugin = (context, inject) => {
    var _a;
    const namespace = "<%= options.namespace || '' %>";
    const port = '<%= options.port %>';
    const cacheInBrowser = "<%= options.cacheInBrowser || '' %>" === 'true';
    const cacheInServer = "<%= options.cacheInServer || '' %>" === 'true';
    let baseURL = namespace;
    if (process.server) {
        baseURL = 'http://0.0.0.0:' + port + namespace;
    }
    const useCache = (process.server && cacheInServer) || (process.client && cacheInBrowser);
    inject('graphql', new GraphqlMiddlewarePlugin(baseURL, (_a = context.req) === null || _a === void 0 ? void 0 : _a.headers, useCache));
};
export default graphqlMiddlewarePlugin;
